@@ -7,6 +7,9 @@ from exchangelib import FileAttachment, ItemAttachment
 from exchangelib import Message as Msg2, Account
 from bs4 import BeautifulSoup
 
+log = logging.getLogger(__name__)
+log.getLogger("exchangelib").setLevel(logging.WARNING)
+
 
 class E2M(Msg):
     def __init__(self, ex_lib_item):
